
From: Domen Puncer <domen@coderock.org>

Inserts a set_current_state(TASK_INTERRUPTIBLE) before the schedule_timeout()
call.  Without this change, after the first iteration of the loop,
schedule_timeout() will not only return immediately, but the loop will break,
as the conditional will no longer be satisfied.  In fact, this conditional
makes little sense given the workings of schedule_timeout.  The timeout
variable is ignored, as well, and I'm fairly certain that it should be
included in the loop conditional.  That way, if the timeout expires before a
signal hits, -ETIME will be returned by fdc_interrupt_wait() instead of
-EINTR.

Signed-off-by: Nishanth Aravamudan <nacc@us.ibm.com>
Signed-off-by: Domen Puncer <domen@coderock.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/char/ftape/lowlevel/fdc-io.c |    3 ++-
 1 files changed, 2 insertions(+), 1 deletion(-)

diff -puN drivers/char/ftape/lowlevel/fdc-io.c~ftape-fdc-io-insert-set_current_state-before-schedule_timeout drivers/char/ftape/lowlevel/fdc-io.c
--- 25/drivers/char/ftape/lowlevel/fdc-io.c~ftape-fdc-io-insert-set_current_state-before-schedule_timeout	2005-03-06 19:57:34.000000000 -0800
+++ 25-akpm/drivers/char/ftape/lowlevel/fdc-io.c	2005-03-06 19:57:34.000000000 -0800
@@ -387,7 +387,8 @@ int fdc_interrupt_wait(unsigned int time
 
 	set_current_state(TASK_INTERRUPTIBLE);
 	add_wait_queue(&ftape_wait_intr, &wait);
-	while (!ft_interrupt_seen && (current->state == TASK_INTERRUPTIBLE)) {
+	while (!ft_interrupt_seen && timeout) {
+		set_current_state(TASK_INTERRUPTIBLE);
 		timeout = schedule_timeout(timeout);
         }
 
_
